<template>
    <el-dialog
        title="整改通知单"
        :visible.sync="dialogVisible"
        width="800px"
        :before-close="handleCloseDialog"
        :close-on-click-modal="false"
        v-if="dialogVisible"
        top="8vh"
    >
        <el-form
            ref="form"
            v-form
            data-vv-scope="form"
            :model="form"
            :rules="userRules"
            label-width="110px"
        >
            <el-row>
                <el-col :span="12">
                    <el-form-item label="整改时限" prop="reformDate">
                        <el-date-picker
                            v-model="form.reformDate"
                            :disabled="disabled"
                            type="date"
                            placeholder="选择日期"
                            format="yyyy-MM-dd"
                            value-format="yyyy-MM-dd"
                            style="width: 100%"
                        >
                        </el-date-picker>
                    </el-form-item>
                </el-col>
                <el-col :span="12">
                    <el-form-item label="整改责任人" prop="reformDepart">
                        <eip-user-selector
                            v-model="form.reformDepart"
                            :permission="disabled ? 'r' : 'b'"
                            :single="true"
                            append-to-body
                            :config="{
                                id: 'form.reformUseId',
                                fullname: 'form.reformDepart',
                            }"
                            placeholder="请选择"
                        />
                    </el-form-item>
                </el-col>
            </el-row>
            <el-row v-if="type == 'record'">
                <el-col :span="12">
                    <el-form-item label="整改类型">
                        <el-select v-model="form.type" :disabled="disabled">
                            <el-option
                                v-for="item in alterType"
                                :label="item.label"
                                :value="item.value"
                                :key="item.value"
                            ></el-option>
                        </el-select>
                    </el-form-item>
                </el-col>
                <el-col :span="12">
                    <el-form-item label="状态">
                        <el-select v-model="form.reformFlag" :disabled="disabled">
                            <el-option
                                v-for="item in flowStatusOptions"
                                :label="item.label"
                                :value="item.value"
                                :key="item.value"
                            ></el-option>
                        </el-select>
                    </el-form-item>
                </el-col>
            </el-row>
            <el-row>
                <el-col :span="24">
                    <el-form-item label="整改要求" prop="reformDescription">
                        <el-input
                            :disabled="disabled"
                            type="textarea"
                            v-model="form.reformDescription"
                            placeholder="整改要求"
                            style="width: 100%"
                        ></el-input>
                    </el-form-item>
                </el-col>
            </el-row>
            <el-row>
                <el-col :span="24">
                    <el-form-item label="整改意见" prop="reformOpinion">
                        <el-input
                            type="textarea"
                            :disabled="disabled"
                            v-model="form.reformOpinion"
                            placeholder="整改意见"
                            style="width: 100%"
                        ></el-input>
                    </el-form-item>
                </el-col>
            </el-row>
            <el-row>
                <el-col :span="24">
                    <el-form-item label="整改前附件">
                        <file-upload
                            :disabled="disabled"
                            :dadToSon="bizEngineeringAccessoriesListBefore"
                            @sonToDad="(data) => sonToDad(data, 'before')"
                        ></file-upload>
                    </el-form-item>
                </el-col>
            </el-row>
            <el-row v-if="disabled">
                <el-col :span="24">
                    <!-- 只有整改填报时该字段可输入 -->
                    <el-form-item
                        label="整改后附件"
                        prop="bizEngineeringAccessoriesListAfter"
                    >
                        <file-upload
                            :disabled="type !== 'flow'"
                            :dadToSon="bizEngineeringAccessoriesListAfter"
                            @sonToDad="(data) => sonToDad(data, 'after')"
                        ></file-upload>
                    </el-form-item>
                </el-col>
            </el-row>
            <el-row v-if="disabled">
                <el-col :span="24">
                    <el-form-item label="整改结果" prop="rectifyResult">
                        <!-- 只有整改填报时该字段可输入 -->
                        <el-input
                            type="textarea"
                            :disabled="type !== 'flow'"
                            v-model="form.rectifyResult"
                            placeholder="整改结果"
                            style="width: 100%"
                        ></el-input>
                    </el-form-item>
                </el-col>
            </el-row>
        </el-form>
        <span slot="footer" class="dialog-footer">
            <el-button @click="handleCancel">取 消</el-button>
            <el-button
                type="primary"
                @click="handleSubmit"
                v-if="type === 'flow' || !type"
            >
                确定
            </el-button>
            <el-button
                type="primary"
                @click="handleApproval(true)"
                v-if="type === 'approval'"
            >
                通过
            </el-button>
            <el-button
                type="warning"
                @click="handleApproval(false)"
                v-if="type === 'approval'"
            >
                驳回
            </el-button>
        </span>
        <processApproval ref="processApproval" @reload="reload" />
    </el-dialog>
</template>

<script>
import eipUserSelector from '@/components/eipControl/selector/EipUserSelector.vue'
import fileUpload from '@/components/upload/fileUploadProject.vue'
import processApproval from './processApproval.vue'
export default {
    name: 'RectificationDialog',
    components: {fileUpload, eipUserSelector, processApproval},
    data() {
        return {
            form: {
                reformFlag: 1,
                reformDepart: '',
                reformUseId: '',
            },
            // 整改前
            bizEngineeringAccessoriesListBefore: {
                bizPath: 'specialproject',
                fileList: [],
            },
            // 整改后
            bizEngineeringAccessoriesListAfter: {
                bizPath: 'specialproject',
                fileList: [],
            },
            dialogVisible: false,
            userRules: {
                reformDepart: {
                    required: true,
                    message: '请输入整改责任人',
                    trigger: 'blur',
                },
                reformDate: {
                    required: true,
                    message: '请选择整改日期',
                    trigger: 'blur',
                },
                reformOpinion: {
                    required: true,
                    message: '请输入整改意见',
                    trigger: 'blur',
                },
                reformDescription: {
                    required: true,
                    message: '请输入整改要求',
                    trigger: 'blur',
                },
                rectifyResult: {
                    required: true,
                    message: '请输入整改结果',
                    trigger: 'blur',
                },
                bizEngineeringAccessoriesListAfter: {
                    required: true,
                    message: '请上传整改后附件',
                    trigger: 'change',
                },
            },
            type: '', // 'approval'审批 'flow'整改 'record'记录查看  ''添加记录
            flowStatusOptions: [
                {
                    label: '待整改',
                    name: '待整改',
                    value: 0,
                },
                {
                    label: '待审批',
                    name: '待审批',
                    value: 1,
                },
                {
                    label: '已完成',
                    name: '已完成',
                    value: 2,
                },
            ],
            alterType: [
                {
                    label: '质量管理',
                    text: '质量管理',
                    value: '1',
                },
                {
                    label: '安全环保',
                    text: '安全环保',
                    value: '2',
                },
            ],
            disable: false,
        }
    },
    methods: {
        reload() {
            this.handleCancel()
            this.$emit('reload')
        },
        handleApproval(flag) {
            this.approvalFlag = flag
            this.$refs.processApproval.handleOpen(this.form, flag, 4) // 4整改
        },
        handleSubmit() {
            if (this.type == 'record') {
                this.handleCancel()
            } else if (this.type == 'flow') {
                this.$refs.form.validate((bool) => {
                    if (bool) {
                        let data = {
                            bizRectificationCommon: this.form,
                            bizEngineeringAccessoriesListBefore:
                                this.bizEngineeringAccessoriesListBefore.fileList || [],
                            bizEngineeringAccessoriesListAfter:
                                this.bizEngineeringAccessoriesListAfter.fileList || [],
                        }

                        delete data.bizRectificationCommon
                            .bizEngineeringAccessoriesListBefore
                        delete data.bizRectificationCommon
                            .bizEngineeringAccessoriesListAfter

                        this.$http
                            .post('${form}/bizRectificationCommon/v1/commit/todo', data)
                            .then((response) => {
                                if (response.data && response.data.state) {
                                    this.$message.success(response.data.message)
                                    this.reload()
                                } else {
                                    this.$message.warning(response.data.message)
                                }
                            })
                    }
                })
            } else {
                this.$refs.form.validate((bool) => {
                    if (bool) {
                        let data = {
                            bizRectificationCommon: this.form,
                            bizEngineeringAccessoriesListBefore:
                                this.bizEngineeringAccessoriesListBefore.fileList || [],
                            bizEngineeringAccessoriesListAfter:
                                this.bizEngineeringAccessoriesListAfter.fileList || [],
                        }
                        this.$emit('handleSave', data)
                        this.handleCancel()
                    }
                })
            }
        },
        open(row, type) {
            this.dialogVisible = true
            if (type) {
                this.type = type
                if (type === 'record' || type === 'flow' || type === 'approval') {
                    this.disabled = true
                }
                this.form = {
                    ...row.bizRectificationCommon,
                    bizEngineeringAccessoriesListBefore:
                        row.bizEngineeringAccessoriesListBefore,
                    bizEngineeringAccessoriesListAfter:
                        row.bizEngineeringAccessoriesListAfter,
                }
            } else {
                this.form = {
                    reformFlag: 1,
                    ...row.bizRectificationCommon,
                    bizEngineeringAccessoriesListBefore:
                        row.bizEngineeringAccessoriesListBefore,
                    bizEngineeringAccessoriesListAfter:
                        row.bizEngineeringAccessoriesListAfter,
                }
            }
            this.bizEngineeringAccessoriesListBefore.fileList =
                row.bizEngineeringAccessoriesListBefore
            this.bizEngineeringAccessoriesListAfter.fileList =
                row.bizEngineeringAccessoriesListAfter
        },
        sonToDad(data, key) {
            let arr = []
            data.forEach((item) => {
                arr.push({
                    isDele: item.isDele,
                    attachmentName: item.name,
                    attachmentPath: item.url,
                    attachmentSuffix: item.suffix,
                    attachmentType: item.type,
                    type: 0,
                })
            })
            if (key == 'before') {
                this.bizEngineeringAccessoriesListBefore.fileList = arr
                this.form.bizEngineeringAccessoriesListBefore = arr.length > 0 ? arr : ''
            }
            if (key == 'after') {
                this.bizEngineeringAccessoriesListAfter.fileList = arr
                this.form.bizEngineeringAccessoriesListAfter = arr.length > 0 ? arr : ''
            }

            // 文件效验
            if (this.form.bizEngineeringAccessoriesListBefore) {
                this.$refs.form.clearValidate('bizEngineeringAccessoriesListBefore')
            } else {
                this.$refs.form.validateField('bizEngineeringAccessoriesListBefore')
            }
            if (this.form.bizEngineeringAccessoriesListAfter) {
                this.$refs.form.clearValidate('bizEngineeringAccessoriesListAfter')
            } else {
                this.$refs.form.validateField('bizEngineeringAccessoriesListAfter')
            }
        },
        //取消弹窗
        handleCancel() {
            this.form = {
                reformFlag: 1,
            }
            this.bizEngineeringAccessoriesListBefore = {
                fileList: [],
            }
            this.bizEngineeringAccessoriesListAfter = {
                fileList: [],
            }
            this.dialogVisible = false
        },
        handleCloseDialog() {
            this.dialogVisible = false
            this.form = {
                reformFlag: 1,
            }
            this.bizEngineeringAccessoriesListBefore = {
                fileList: [],
            }
            this.bizEngineeringAccessoriesListAfter = {
                fileList: [],
            }
        },
    },
}
</script>

<style lang='scss' scoped>
/deep/.el-dialog__header{
    text-align: center;
}
</style>
